@@ -36,12 +36,12 @@ class SolutionStateManager:
     required_new_job_fields = [
         "TrainingJobName",
         'AlgorithmSpecification',
-        'HyperParameters'
-        'InputDataConfig'
+        'HyperParameters',
+        'InputDataConfig',
         'OutputDataConfig',
         'ResourceConfig',
         'EnableManagedSpotTraining',
-        'RoleARN',
+        'RoleArn',
         'StoppingCondition'
     ]
 
@@ -56,14 +56,20 @@ class SolutionStateManager:
         self.sagemaker = boto3.client('sagemaker')
 
     # pylint: disable=invalid-name
-    def sagemaker_create_solution(self, TrainingJobName: str, newSolutionName: str):
-        """
-            Performs a create solution API execution to create new solution version job
+    def sagemaker_create_solution(self, training_job_name: str, new_solution_name: str) -> str:
+        """Performs a create solution API execution to create new solution version job
+
+            Args:
+                training_job_name (str): name of previously successful training job
+                new_solution_name (str): new training job name
+
+            Returns:
+                (str) : new training job name
         """
 
         # get current solution
         prev_training_job = self.sagemaker.describe_training_job(
-            TrainingJobName=TrainingJobName
+            TrainingJobName=training_job_name
         )
 
         new_training_job = {}
@@ -76,7 +82,7 @@ class SolutionStateManager:
         # update fields
         # in python3, a time suffix is automatically added
         new_training_job.update({
-            'TrainingJobName': newSolutionName
+            'TrainingJobName': new_solution_name
         })
 
         self.sagemaker.create_training_job(**new_training_job)
@@ -211,8 +217,8 @@ class SolutionStateManager:
         }
 
         new_solution_arn = self.sagemaker_create_solution(
-            TrainingJobName=solution['arn'],
-            newSolutionName=solution_base_name
+            training_job_name=solution['arn'],
+            new_solution_name=solution_base_name
         )
         # update the arn with the new arn
         new_solution.update({
